@@ -16,6 +16,9 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
 
 /* incorporates color features added by Bruno ALIX */
 
