@@ -16,13 +16,16 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
 
 #include <stdlib.h>
 #include <string.h>
 #include <math.h>
 #define __IMAGE_C__
 
-#include "syslog.h"
+#include "ppa_syslog.h"
 #include "global.h"
 #include "defaults.h"
 
