@@ -15,6 +15,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -26,7 +30,7 @@
 
 #define __PNM2PPA_C__
 
-#include "syslog.h"
+#include "ppa_syslog.h"
 #include "global.h"
 #include "image.h"
 #include "debug.h"
@@ -286,7 +290,7 @@ show_usage (char *prog)
     printf
       ("  The order in which parameters are specified is important:\n");
     printf
-      ("  the file /etc/pnm2ppa.conf, if it exists, is processed as a configuration\n");
+      ("  the file %s, if it exists, is processed as a configuration\n", defaultcfgfile);
     printf 
       ("  file before any command-line parameters are processed.\n");
     printf 
@@ -399,7 +403,7 @@ dump_config (void)
     exit (0);
 }
 
-/* only let gSilent be set to switch off syslog from /etc/pnm2ppa.conf, 
+/* only let gSilent be set to switch off syslog from $SYSCONFDIR/etc/pnm2ppa.conf, 
    and  not from
    subsequent readings of config files 
 */
@@ -626,7 +630,7 @@ main (int argc, char *argv[])
   int i, opt_index;
   FILE *in = NULL, *out = NULL, *gf = NULL;
   struct stat tmpstat;
-  char c;
+  int c;
   BOOLEAN get_Gamma = true;
 
   char gammaFile[MAXPATHLEN];
