@@ -15,6 +15,10 @@
  *                                                                         *
  ***************************************************************************/
 
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -22,7 +26,7 @@
 
 #define __PPA_C__
 
-#include "syslog.h"
+#include "ppa_syslog.h"
 #include "global.h"
 #include "ppa.h"
 #include "debug.h"
